==> wetterdienst-0.99.0.tar.gz: wetterdienst-0.99.0/docs/data/provider/ea/hydrology/daily.md <==
# daily

## metadata

| property      | value                                                                                          |
|---------------|------------------------------------------------------------------------------------------------|
| name          | daily                                                                                          |
| original name | daily                                                                                          |
| url           | [here](https://environment.data.gov.uk/hydrology/doc/reference)                                |

## datasets

### data

#### metadata

| property      | value                                                                          |
|---------------|--------------------------------------------------------------------------------|
| name          | data                                                                           |
| original name | data                                                                           |
| description   | Historical daily station observations of flow and groundwater level for the UK |
| access        | [here](https://environment.data.gov.uk/hydrology/doc/reference)                |

#### parameters

| name              | original name     | description                  | unit | original unit | constraints |
|-------------------|-------------------|------------------------------|------|---------------|-------------|
| flow              | water flow        | daily mean flow              | m³/s | m³/s          | >=0         |
| groundwater_level | groundwater level | daily mean groundwater level | m    | m             | >=0         |

==> wetterdienst-0.100.0.tar.gz: wetterdienst-0.100.0/docs/data/provider/ea/hydrology/daily.md <==
# daily

## metadata

| property      | value                                                                                          |
|---------------|------------------------------------------------------------------------------------------------|
| name          | daily                                                                                          |
| original name | daily                                                                                          |
| url           | [here](https://environment.data.gov.uk/hydrology/doc/reference)                                |

## datasets

### data

#### metadata

| property      | value                                                                          |
|---------------|--------------------------------------------------------------------------------|
| name          | data                                                                           |
| original name | data                                                                           |
| description   | Historical daily station observations of flow and groundwater level for the UK |
| access        | [here](https://environment.data.gov.uk/hydrology/doc/reference)                |

#### parameters

| name              | original name     | description                  | unit type       | unit          | constraints |
|-------------------|-------------------|------------------------------|-----------------|---------------|-------------|
| flow              | water flow        | daily mean flow              | volume_per_time | m³/s          | >=0         |
| groundwater_level | groundwater level | daily mean groundwater level | length_medium   | m             | >=0         |
